/*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*/
/*~									    														  ~*/
/*~	    		        Copyright  2003 Freeware Inc.      					     ~*/
/*~														 						   			  ~*/
/*~   		  		       Freeware 3D Clock Library 	    				        ~*/
/*~									    														  ~*/
/*~		 		  Written by Alper YAZGAN,  alperyazgan@hotmail.com 			  ~*/
/*~									    														  ~*/
/*~   		    	      		   IV-MMIII				    							  ~*/
/*~									    														  ~*/
/*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*/

//---------------------------------------------------------------------------
#ifndef Clock3DH
#define Clock3DH
//---------------------------------------------------------------------------
#include <SysUtils.hpp>
#include <Classes.hpp>
#include <Controls.hpp>
//---------------------------------------------------------------------------
#include "Clock3DAbout.h"
//---------------------------------------------------------------------------
namespace Clock3d
{

class PACKAGE TClock3D : public TCustomControl
{
private:
  class TClockThread : public TThread
  {
    private:
      TClock3D *Clock3DOwner;
    protected:
      void __fastcall Execute(void);
    public:
      __fastcall TClockThread(TClock3D *Owner);
  };

  friend class TClockThread;

  enum TClockStyle { csRingShapedClock, csTwistedClock };

  enum THourStyle { hs24HourTime, hs12HourTime };

  int FilledDotLines;
  TDateTime CurrentTime;
  int FramesPerSec;
  int PixelDistance;
  int ClockColorDepth;
  int ClockDistanceColorFactor;
  int PixelDistanceX120;
  int ClockDotLine7[150];
  int ClockDotLine6[150];
  int ClockDotLine5[150];
  int ClockDotLine4[150];
  int ClockDotLine3[150];
  int ClockDotLine2[150];
  int ClockDotLine1[150];
  int CurrentTimeHours;
  int CurrentTimeMinutes;
  int CurrentTimeSeconds;
  int InitialAngleInYAxis;
  int InitialAngleInXAxis;
  int InitialAngleInZAxis;
  int RotationXAxis;
  int RotationYAxis;
  int RotationZAxis;
  int HourStyleMuptiplier;
  TColor ClockColors[65];
  int DigitArray[12][51];
  TClockThread *DrawThread;
  int Clock180[180];
  TClockStyle FClockStyle;
  THourStyle FClockHourStyle;
  int FFramesPerSecond;
  int FPixDistance;
  int FPixelAngle;
  int FClockRadius;
  int FClockDistance;
  double FRotX;
  double FRotY;
  double FRotZ;
  int FIRotX;
  int FIRotY;
  int FIRotZ;
  TColor FClockColor;
  TPicture *FBackgroundImage;
  int FImageSourcePointX;
  int FImageSourcePointY;
  bool FActive;
  bool FStretched;
  TClock3DAbout FAbout;
  void __fastcall SetStyle(void);
  void __fastcall SetClockStyle(TClockStyle Value);
  void __fastcall SetClockHourStyle(THourStyle Value);
  void __fastcall SetFramesPerSecond(int Value);
  void __fastcall SetPixDistance(int Value);
  void __fastcall SetPixelAngle(int Value);
  void __fastcall SetClockRadius(int Value);
  void __fastcall SetClockDistance(int Value);
  void __fastcall SetRotX(double Value);
  void __fastcall SetRotY(double Value);
  void __fastcall SetRotZ(double Value);
  void __fastcall SetIRotX(int Value);
  void __fastcall SetIRotY(int Value);
  void __fastcall SetIRotZ(int Value);
  void __fastcall SetColor(void);
  void __fastcall SetClockColor(TColor Value);
  void __fastcall SetBackgroundImage(TPicture *Value);
  void __fastcall SetImageSourcePointX(int Value);
  void __fastcall SetImageSourcePointY(int Value);
  void __fastcall SetActive(bool Value);
  void __fastcall SetStretched(bool Value);
  void __fastcall SetPriority(TThreadPriority Value);
  TThreadPriority __fastcall GetPriority(void);
  void __fastcall SetTransparent(bool Value);
  void __fastcall CalculateClockTimeDots(void);
  int __fastcall Cosine(int i);
  int __fastcall Sine(int i);
  void __fastcall FillDotLines(void);
  void __fastcall DrawClockDots(void);

protected:
  virtual void __fastcall Paint(void);
  virtual void __fastcall WndProc(Messages::TMessage &Message);

__published:
  __property Width = { default = 128 };
  __property Height = { default = 128 };
  __property Anchors;
  __property Constraints;
  __property Color;
  __property ParentColor;
  __property OnClick;
  __property OnDblClick;
  __property bool Active = { read = FActive, write = SetActive, default = false };
  __property int FramesPerSecond  = { read = FFramesPerSecond, write = SetFramesPerSecond, default = 26 };
  __property TClockStyle ClockStyle  = { read = FClockStyle, write = SetClockStyle, default = csRingShapedClock };
  __property THourStyle ClockHourStyle  = { read = FClockHourStyle, write = SetClockHourStyle, default = hs24HourTime };
  __property int PixDistance  = { read = FPixDistance, write = SetPixDistance, default = 24 };
  __property int PixelAngle  = { read = FPixelAngle, write = SetPixelAngle, default = 6 };
  __property int ClockRadius  = { read = FClockRadius, write = SetClockRadius, default = 24 };
  __property int ClockDistance  = { read = FClockDistance, write = SetClockDistance, default = 15000 };
  __property double RotX  = { read = FRotX, write = SetRotX };
  __property double RotY  = { read = FRotY, write = SetRotY };
  __property double RotZ  = { read = FRotZ, write = SetRotZ };
  __property int IRotX  = { read = FIRotX, write = SetIRotX, default = 0 };
  __property int IRotY  = { read = FIRotY, write = SetIRotY, default = 0 };
  __property int IRotZ  = { read = FIRotZ, write = SetIRotZ, default = 30 };
  __property TColor ClockColor  = { read = FClockColor, write = SetClockColor, default = 0x0055FF88 };
  __property TPicture *BackgroundImage  = { read = FBackgroundImage, write = SetBackgroundImage };
  __property int ImageSourcePointX  = { read = FImageSourcePointX, write = SetImageSourcePointX, default = 0 };
  __property int ImageSourcePointY  = { read = FImageSourcePointY, write = SetImageSourcePointY, default = 0 };
  __property bool Stretched = { read = FStretched, write = SetStretched, default = false };
  __property TThreadPriority Priority = { read = GetPriority, write = SetPriority, default = tpIdle };
  __property TClock3DAbout About = { read = FAbout, stored = false };

public:
  __fastcall TClock3D(TComponent* Owner);
  __fastcall ~TClock3D(void);
};

};
//---------------------------------------------------------------------------
#if !defined(NO_IMPLICIT_NAMESPACE_USE)
using namespace Clock3d;
#endif
//---------------------------------------------------------------------------
#endif
